@@ -34,37 +34,125 @@ from commons.models import Address
 from masterdata.models import TimeSheet
 from masterdata.models import TimeSheetStatistic
 from masterdata.models import TimeSheetItem
+import calendar
+from random import choice, randint
 
 class Command(BaseCommand):
     help = _('Személyre szabott törzsadatok generálása.')
 
+    LOCATIONS = [
+        'Budapest',
+        'Debrecen',
+        'Győr'
+        'Kecskemét',
+        'Szeged',
+        'Washington'
+    ]
+
+    STREETS = [
+        'Marx Károly',
+        'Moszkva',
+        'Dob',
+        'Szervita'
+    ]
+
+    MALE_FIRST_NAMES = [
+        'Árpád',
+        'Előd',
+        'Ond',
+        'Kond',
+        'Tas',
+        'Huba',
+        'Töhötöm',
+        'Taksony',
+        'Zalán',
+        'Álmos',
+        'Kende',
+        'Vajk',
+        'Manfréd'
+    ]
+
+    ORGANIZATION_NAMES = [
+        'Mega',
+        'Globál',
+        'Hiper',
+        'Szuper',
+        'Top',
+        'Elite',
+        'Professional'
+    ]
+
+    FEMALE_FIRST_NAMES = [
+        'Alexandra',
+        'Antónia',
+        'Lukrécia',
+        'Petúnia',
+        'Virág'
+    ]
+
+    FAMILY_NAMES = [
+        'Zwack',
+        'Vad',
+        'Kovács',
+        'Juhász',
+        'Corvin',
+        'Bálthy',
+        'Kossuth',
+    ]
+
     def add_arguments(self, parser):
         pass
 
     def handle(self, *args, **options):
 
-        self.generate_appliance_qualities()
-        self.generate_autonome_activity_statements()
-        self.generate_business_forms()
-        self.generate_contributions()
-        self.generate_dependent_qualities()
-        self.generate_dependent_rights()
+        Organization.objects.all().delete()
+        Individual.objects.all().delete()
+        Customer.objects.all().delete()
+        TimeSheet.objects.all().delete()
+
+        ApplianceQuality.objects.all().delete()
+        AutonomeActivityStatement.objects.all().delete()
+        BusinessForm.objects.all().delete()
+        Contribution.objects.all().delete()
+        Tax.objects.all().delete()
+        Discount.objects.all().delete()
+        DependentQuality.objects.all().delete()
+        DependentRight.objects.all().delete()
+        FamilyTaxDiscountStatement.objects.all().delete()
+        Legal.objects.all().delete()
+        PauseCategory.objects.all().delete()
+        PayrollMode.objects.all().delete()
+        Pretence.objects.all().delete()
+        PrimeMarriageStatement.objects.all().delete()
+        RevenueBase.objects.all().delete()
+        RevenueType.objects.all().delete()
+        TimeSheetCategory.objects.all().delete()
+        Title.objects.all().delete()
+        UniformBookingClassificationSystem.objects.all().delete()
+
+        self.create_appliance_qualities()
+        self.create_autonome_activity_statements()
+        self.create_business_forms()
+        self.create_contributions()
+        self.create_dependent_qualities()
+        self.create_dependent_rights()
         # TODO: discounts?
-        self.generate_family_tax_discount_statements()
-        self.generate_legals()
-        self.generate_categories_pause()
-        self.generate_payrollmode()
-        self.generate_pretences()
-        self.generate_prime_marriage_statements()
-        self.generate_revenue_bases()
-        self.generate_revenue_types()
-        self.generate_taxes()
-        self.generate_categories_timesheet()
-        self.generate_titles()
-        self.generate_uniform_booking_classification_system()
+        self.create_family_tax_discount_statements()
+        self.create_legals()
+        self.create_categories_pause()
+        self.create_payrollmode()
+        self.create_pretences()
+        self.create_prime_marriage_statements()
+        self.create_revenue_bases()
+        self.create_revenue_types()
+        self.create_taxes()
+        self.create_categories_timesheet()
+        self.create_titles()
+        self.create_uniform_booking_classification_system()
 
         self.stdout.write("Adatlapok generálása ... %s" % self.style.SUCCESS("OK"))
-        self.generate_persons()
+        self.generate_persons(firstnames=self.FEMALE_FIRST_NAMES, amount=10)
+        self.generate_persons(firstnames=self.MALE_FIRST_NAMES, amount=20)
         self.generate_individuals()
         self.generate_organizations()
 
@@ -72,36 +160,33 @@ class Command(BaseCommand):
         self.log_pauses()
         self.log_timesheets()
 
-    def generate_family_tax_discount_statements(self):
+    def create_family_tax_discount_statements(self):
         """
         Laki-Studio családi adókedvezmény nyilatkozat törzs generálása
         :return:
         """
-        FamilyTaxDiscountStatement.objects.all().delete()
         self.stdout.write('Setup: %s törzs (%s record) ... %s' % (
             FamilyTaxDiscountStatement._meta.verbose_name.title(),
             FamilyTaxDiscountStatement.objects.count(),
             self.style.SUCCESS("OK")
         ))
 
-    def generate_uniform_booking_classification_system(self):
+    def create_uniform_booking_classification_system(self):
         """
         Laki-Studio FEOR törzs generálása
         :return:
         """
-        UniformBookingClassificationSystem.objects.all().delete()
         self.stdout.write('Setup: %s törzs (%s record) ... %s' % (
             UniformBookingClassificationSystem._meta.verbose_name.title(),
             UniformBookingClassificationSystem.objects.count(),
             self.style.SUCCESS("OK")
         ))
 
-    def generate_autonome_activity_statements(self):
+    def create_autonome_activity_statements(self):
         """
         Laki-Studio önálló tevékenység nyilatkozat törzs generálása
         :return:
         """
-        AutonomeActivityStatement.objects.all().delete()
         AutonomeActivityStatement.objects.create(code="", name="Nem tett nyilatkozatot")
         AutonomeActivityStatement.objects.create(code="", name="10%-os költséghányad figyelembe vétele")
         AutonomeActivityStatement.objects.create(code="", name="SZJA tv. 3. melléklet II. fejezete szerintibizonylat nélkül elszámolható költség")
@@ -113,12 +198,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_dependent_qualities(self):
+    def create_dependent_qualities(self):
         """
         Laki-Studio eltartott jogosultság törzs generálása
         :return:
         """
-        DependentQuality.objects.all().delete()
         DependentQuality.objects.create(code="0", name="Kedvezménybe nem számítható")
         DependentQuality.objects.create(code="1", name="Kedvezményezett eltartott")
         DependentQuality.objects.create(code="2", name="Eltartott")
@@ -130,12 +214,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_dependent_rights(self):
+    def create_dependent_rights(self):
         """
         Laki-Studio eltartott jogosultság törzs generálása
         :return:
         """
-        DependentRight.objects.all().delete()
         DependentRight.objects.create(code="0", name="Kedvezménybe nem számítható")
         DependentRight.objects.create(code="4", name="Gyermek után családi pótlékra jogosult vagy ilyen jogosulttal közös háztartásban élő házastárs de családi pótlékra nem jogossult")
         DependentRight.objects.create(code="5", name="Családi pótlékra saját jogán jogosult vagy ilyen jogosulttal közös háztartásban élő hozzátartozó")
@@ -148,12 +231,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_appliance_qualities(self):
+    def create_appliance_qualities(self):
         """
         Laki-Studio alkalmazás minősége törzs generálása
         :return:
         """
-        ApplianceQuality.objects.all().delete()
         ApplianceQuality.objects.create(code="20", name="munkaviszony, több munkáltatóval létesített munkaviszony, bedolgozói munkaviszony")
         ApplianceQuality.objects.create(code="71", name="közalkalmazotti jogviszony")
         ApplianceQuality.objects.create(code="72", name="közszolgálati jogviszony")
@@ -229,12 +311,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_payrollmode(self):
+    def create_payrollmode(self):
         """
         Laki-Studio önálló tevékenység nyilatkozat törzs generálása
         :return:
         """
-        PayrollMode.objects.all().delete()
         PayrollMode.objects.create(code="", name="Havibér normál munkarend")
         PayrollMode.objects.create(code="", name="Havibér egyenlőtlen munkarend (munkaidőkeret)")
         PayrollMode.objects.create(code="", name="Órabér")
@@ -248,12 +329,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_prime_marriage_statements(self):
+    def create_prime_marriage_statements(self):
         """
         Laki-Studio első házasok nyilatkozat törzs generálása
         :return:
         """
-        PrimeMarriageStatement.objects.all().delete()
         PrimeMarriageStatement.objects.create(code="", name="Nem vesz igénybe családi kedvezményt")
         PrimeMarriageStatement.objects.create(code="", name="Megosztás nélkül veszi igénybe a családi kedvezményt")
         PrimeMarriageStatement.objects.create(code="", name="Megosztással veszi igénybe a családi kedvezményt")
@@ -264,12 +344,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_titles(self):
+    def create_titles(self):
         """
         Laki-Studio előtag törzs generálása
         :return:
         """
-        Title.objects.all().delete()
         Title.objects.create(code="dr",name="Dr.")
         Title.objects.create(code="drdr",name="Dr. Dr.")
         Title.objects.create(code="drpr",name="Dr. Pr.")
@@ -288,35 +367,34 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_business_forms(self):
+    def create_business_forms(self):
         """
         Laki-Studio cégformák törzs generálása
         :return:
         """
-        BusinessForm.objects.all().delete()
-        BusinessForm.objects.create(code="", name="Európai szövetkezet")
-        BusinessForm.objects.create(code="", name="Külföldi székhelyű európai gazdasági egyesülés magyarországi telephelye")
-        BusinessForm.objects.create(code="", name="Közjegyzői iroda")
-        BusinessForm.objects.create(code="", name="Európai részvénytársaság")
-        BusinessForm.objects.create(code="", name="Európai gazdasági egyesülés")
-        BusinessForm.objects.create(code="", name="Végrehajtói iroda")
-        BusinessForm.objects.create(code="", name="Külföldi vállalkozás magyarországi fióktelepe")
-        BusinessForm.objects.create(code="", name="Vízgazdálkodási társulat")
-        BusinessForm.objects.create(code="", name="Erdőbirtokossági társulat")
-        BusinessForm.objects.create(code="", name="Közhasznú társaság")
-        BusinessForm.objects.create(code="", name="Oktatói munkaközösség")
-        BusinessForm.objects.create(code="", name="Külföldiek magyarországi közvetlen kereskedelmi képviselete")
-        BusinessForm.objects.create(code="", name="Egyéni cég")
-        BusinessForm.objects.create(code="", name="Részvénytársaság")
-        BusinessForm.objects.create(code="kft", name="Korlátolt felelősségű társaság")
-        BusinessForm.objects.create(code="", name="Közös vállalat")
-        BusinessForm.objects.create(code="", name="Egyesülés")
-        BusinessForm.objects.create(code="", name="Betéti társaság")
-        BusinessForm.objects.create(code="", name="Jogi személy felelősségvállalásával működő gazdasági munkaközösség")
-        BusinessForm.objects.create(code="", name="Gazdasági munkaközösség")
-        BusinessForm.objects.create(code="", name="Közkereseti társaság")
-        BusinessForm.objects.create(code="", name="Szövetkezet")
-        BusinessForm.objects.create(code="", name="Vállalat")
+        BusinessForm.objects.create(code="01", name="Európai szövetkezet")
+        BusinessForm.objects.create(code="02", name="Külföldi székhelyű európai gazdasági egyesülés magyarországi telephelye")
+        BusinessForm.objects.create(code="03", name="Közjegyzői iroda")
+        BusinessForm.objects.create(code="04", name="Európai részvénytársaság")
+        BusinessForm.objects.create(code="05", name="Európai gazdasági egyesülés")
+        BusinessForm.objects.create(code="06", name="Végrehajtói iroda")
+        BusinessForm.objects.create(code="07", name="Külföldi vállalkozás magyarországi fióktelepe")
+        BusinessForm.objects.create(code="08", name="Vízgazdálkodási társulat")
+        BusinessForm.objects.create(code="09", name="Erdőbirtokossági társulat")
+        BusinessForm.objects.create(code="10", name="Közhasznú társaság")
+        BusinessForm.objects.create(code="11", name="Oktatói munkaközösség")
+        BusinessForm.objects.create(code="12", name="Külföldiek magyarországi közvetlen kereskedelmi képviselete")
+        BusinessForm.objects.create(code="13", name="Egyéni cég")
+        BusinessForm.objects.create(code="14", name="Részvénytársaság")
+        BusinessForm.objects.create(code="15", name="Korlátolt felelősségű társaság")
+        BusinessForm.objects.create(code="16", name="Közös vállalat")
+        BusinessForm.objects.create(code="17", name="Egyesülés")
+        BusinessForm.objects.create(code="18", name="Betéti társaság")
+        BusinessForm.objects.create(code="19", name="Jogi személy felelősségvállalásával működő gazdasági munkaközösség")
+        BusinessForm.objects.create(code="20", name="Gazdasági munkaközösség")
+        BusinessForm.objects.create(code="21", name="Közkereseti társaság")
+        BusinessForm.objects.create(code="22", name="Szövetkezet")
+        BusinessForm.objects.create(code="23", name="Vállalat")
 
         self.stdout.write('Setup: %s törzs (%s record) ... %s' % (
             BusinessForm._meta.verbose_name.title(),
@@ -324,12 +402,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_contributions(self):
+    def create_contributions(self):
         """
         Laki-Studio járulék törzs generálása
         :return:
         """
-        Contribution.objects.all().delete()
         Contribution.objects.create(
             code="ebpm",
             name="NAV Egészségbiztosítási és munkaerő-piaci járulék magánszemélyt, őstermelőt, egyéni vállalkozót, kifizetőt terhelő kötelezettség"
@@ -353,12 +430,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_categories_timesheet(self):
+    def create_categories_timesheet(self):
         """
         Laki-Studio jelenléti blokk törzs generálása
         :return:
         """
-        TimeSheetCategory.objects.all().delete()
         TimeSheetCategory.objects.create(code="X", name="Ledolgozott napok")
         TimeSheetCategory.objects.create(code="F", name="Fizetett ünnep / Munkaszüneti nap")
         TimeSheetCategory.objects.create(code="I", name="Fizetett igazolt távollét")
@@ -376,12 +452,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_categories_pause(self):
+    def create_categories_pause(self):
         """
         Laki-Studió biztosítási törzsadatok generálása.
         :return:
         """
-        PauseCategory.objects.all().delete()
         PauseCategory.objects.create(code="11",name="táppénz")
         PauseCategory.objects.create(code="12",name="baleseti táppénz")
         PauseCategory.objects.create(code="21",name="csecsemőgondozási díj")
@@ -409,13 +484,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_taxes(self):
+    def create_taxes(self):
         """
         Laki-Studio adónemek törzs generálása.
         :return:
         """
-        Discount.objects.all().delete()
-        Tax.objects.all().delete()
 
         Tax.objects.create(code="", name="Rehabilitációs hozzájárulás")
 
@@ -433,13 +506,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_legals(self):
+    def create_legals(self):
         """
         Laki-Studio saját jogviszony törzs generálása.
         :return:
         """
-        Legal.objects.all().delete()
-
         Legal.objects.create(code="", name="Normál alkalmazott")
         Legal.objects.create(code="", name="Nyugdíjas alkalmazott")
         Legal.objects.create(code="", name="Főfoglalkozású társas vállalkozó (munkaviszonyos)")
@@ -468,13 +539,12 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_pretences(self):
+    def create_pretences(self):
         """
         Laki-Studio saját jogcím törzs generálása.
 
         :return:
         """
-        Pretence.objects.all().delete()
         Pretence.objects.create(code="AL", name="Állásidő")
         Pretence.objects.create(code="LM", name="Munkabér")
         Pretence.objects.create(code="BS", name="Betegszabadság")
@@ -524,7 +594,6 @@ class Command(BaseCommand):
         Laki-Studio EKHO adózási limit törzs generálása
         :return:
         """
-        SimplifiedBurdenSharingContributionTaxLimit.objects.all().delete()
         SimplifiedBurdenSharingContributionTaxLimit.objects.create(code="", name="Meghatározott feor és nyugdíjas magánszemély - 60M")
         SimplifiedBurdenSharingContributionTaxLimit.objects.create(code="", name="Sportszervezet edzője - 250M")
         SimplifiedBurdenSharingContributionTaxLimit.objects.create(code="", name="Hivatásos sportoló - 500M")
@@ -535,12 +604,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_revenue_types(self):
+    def create_revenue_types(self):
         """
         Laki-Studio jövedelem típusa törzs generálása
         :return:
         """
-        RevenueType.objects.all().delete()
         RevenueType.objects.create(code="", name="Munkaviszonyból származó bérjövedelem")
         RevenueType.objects.create(code="", name="Munkaviszonnyal kapcsolatos költségtérítés")
         RevenueType.objects.create(code="", name="Külszolgálatért kapott jövedelem")
@@ -562,7 +630,6 @@ class Command(BaseCommand):
         Laki-Studio jövedelem alapja törzs generálása
         :return:
         """
-        RevenueBase.objects.all().delete()
         RevenueBase.objects.create(code="", name="Egyösszegű kifizetés")
         RevenueBase.objects.create(code="", name="Óra/nap")
         RevenueBase.objects.create(code="", name="Óra")
@@ -573,12 +640,11 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_revenue_bases(self):
+    def create_revenue_bases(self):
         """
         Laki-Studio családi adókedvezmény nyilatkozat törzs generálása
         :return:
         """
-        FamilyTaxDiscountStatement.objects.all().delete()
         FamilyTaxDiscountStatement.objects.create(code="", name="Nem vesz igénybe családi kedvezményt")
         FamilyTaxDiscountStatement.objects.create(code="", name="Megosztás nélkül veszi igénybe a családi kedvezményt")
         FamilyTaxDiscountStatement.objects.create(code="", name="Megosztással veszi igénybe a családi kedvezményt")
@@ -589,80 +655,130 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
-    def generate_persons(self):
-        """
-        Példa személyi addatlapok generálása
-        :return:
-        """
-        Address.objects.all().delete()
-        Person.objects.all().delete()
+    def generate_persons(self, firstnames=[], gender=gender_female, amount=10):
 
-        address = Address.objects.create(street_number=11,route='Kócsag')
+        for index in range(0, amount):
+            year = randint(1920, 2020)
+            month = randint(1, 12)
+            day = randint(*calendar.monthrange(year, month)) % 28
+            city = choice(self.LOCATIONS)
+            street = choice(self.STREETS)
+            street_number = randint(1, 200)
+            address = Address(raw='{street} utca {street_number}, {city}, Hungary'.format(
+                city=city,
+                street=street,
+                street_number=street_number,
+            ))
+            address.save()
 
-        self.ofelia_bartok = Person.objects.create(
-            gender=gender_female,
-            birthdate=datetime(year=1957, month=5, day=19),
-            birthplace="Csengele",
-            name_of_mother="Karczag Tímea",
-            first_name="Ofélia",
-            last_name="Bartók",
-            permanent_address=address,
-            nationality='hu',
-            inland_resident=True,
-            tax_number='0011344'
-        )
+            Person.objects.get_or_create(
+                first_name=choice(firstnames),
+                last_name=choice(self.FAMILY_NAMES),
+                gender=gender_female,
+                birthdate=datetime(year=year, month=month, day=day),
+                birthplace=choice(self.LOCATIONS),
+                name_of_mother="{last} {first}".format(
+                    last=choice(self.FAMILY_NAMES),
+                    first=choice(self.FEMALE_FIRST_NAMES)
+                ),
+                permanent_address=address,
+                nationality='hu',
+                inland_resident=True,
+                tax_number='8{p26}{p79}{p0}'.format(
+                    p26=(datetime(year=year,month=month,day=day)-datetime(year=1867,month=1,day=1)).days,
+                    p79=randint(100, 999),
+                    p0=randint(1, 9),
+                ),
 
-        self.manfred_csele = Person.objects.create(
-            gender=gender_male,
-            birthdate=datetime(year=1980, month=6, day=11),
-            birthplace="Szeged",
-            name_of_mother="Boros Katalin",
-            first_name="Manfréd",
-            last_name="Csele",
-            permanent_address=address,
-            nationality='hu',
-            inland_resident=True,
-            tax_number='0011344'
-        )
+            )
 
-        self.csanad_bornemissza = Person.objects.create(
-            gender=gender_male,
-            birthdate=datetime(year=1933, month=3, day=23),
-            birthplace="Budapest",
-            name_of_mother="Varnusz Titánia",
-            first_name="Csanád",
-            last_name="Bornemissza",
-            permanent_address=address,
-            nationality='hu',
-            inland_resident=True,
-            tax_number='0011344'
-        )
+    # def generate_persons(self):
+    #     """
+    #     Példa személyi addatlapok generálása
+    #     :return:
+    #     """
 
-    def generate_organizations(self):
+    #
+    #     address = Address.objects.create(street_number=11,route='Kócsag')
+    #
+    #     self.ofelia_bartok = Person.objects.create(
+    #         gender=gender_female,
+    #         birthdate=datetime(year=1957, month=5, day=19),
+    #         birthplace="Csengele",
+    #         name_of_mother="Karczag Tímea",
+    #         first_name="Ofélia",
+    #         last_name="Bartók",
+    #         permanent_address=address,
+    #         nationality='hu',
+    #         inland_resident=True,
+    #         tax_number='0011344'
+    #     )
+    #
+    #     self.manfred_csele = Person.objects.create(
+    #         gender=gender_male,
+    #         birthdate=datetime(year=1980, month=6, day=11),
+    #         birthplace="Szeged",
+    #         name_of_mother="Boros Katalin",
+    #         first_name="Manfréd",
+    #         last_name="Csele",
+    #         permanent_address=address,
+    #         nationality='hu',
+    #         inland_resident=True,
+    #         tax_number='0011344'
+    #     )
+    #
+    #     self.csanad_bornemissza = Person.objects.create(
+    #         gender=gender_male,
+    #         birthdate=datetime(year=1933, month=3, day=23),
+    #         birthplace="Budapest",
+    #         name_of_mother="Varnusz Titánia",
+    #         first_name="Csanád",
+    #         last_name="Bornemissza",
+    #         permanent_address=address,
+    #         nationality='hu',
+    #         inland_resident=True,
+    #         tax_number='0011344'
+    #     )
+
+    def generate_organizations(self, amount=15):
         """
         Példa társas vállakozások generálása
         :return:
         """
-        Organization.objects.all().delete()
+        for index in range(0, amount):
+            bf = choice(BusinessForm.objects.all())
+            Organization.objects.create_organization(
+                name='{a}-{b} Kft.'.format(
+                    a=choice(self.ORGANIZATION_NAMES),
+                    b=choice(self.ORGANIZATION_NAMES),
+                ),
+                manager=choice(Person.objects.all()),
+                registration_number='{bs}-{cf}-{nnnnnn}'.format(
+                    bs=randint(10, 50),
+                    cf=str(randint(1, 23)),
+                    nnnnnn=randint(100000, 999999)
+                ),
+                business_form=bf,
+                tax_number='{xxxxxxxx}-{y}-{zz}'.format(
+                    xxxxxxxx=randint(10000000, 99999999),
+                    y=randint(1, 5),
+                    zz=randint(1, 40),
+                )
+            )
 
-        Organization.objects.create(
-            name='MegaGlobál',
-            manager=self.manfred_csele,
-            registration_number='123456',
-            business_form=BusinessForm.objects.get(code='kft')
-        )
-
-    def generate_individuals(self):
+    def generate_individuals(self, amount=5):
         """
         Példa egyéni vállalkozások generálása
         :return:
         """
-        Individual.objects.all().delete()
-
-        Individual.objects.create(owner=self.csanad_bornemissza)
+        for index in range(0, amount):
+            person = choice(Person.objects.all())
+            Individual.objects.create_individual(
+                owner=person,
+                name='{display_name} EV'.format(display_name=person.full_name)
+            )
 
     def log_pauses(self):
-        Pause.objects.all().delete()
 
         c11 = PauseCategory.objects.get(code="11")
         c41 = PauseCategory.objects.get(code="41")
@@ -678,8 +794,6 @@ class Command(BaseCommand):
         Pause.objects.create(category=c71, begin=d_2020_01_15, end=d_2020_01_29)
 
     def log_timesheets(self):
-        TimeSheetItem.objects.all().delete()
-        TimeSheet.objects.all().delete()
 
 
         cX = TimeSheetCategory.objects.get(code="X")
