@@ -1,6 +1,6 @@
 from django.contrib.syndication.views import Feed
 from django.urls import reverse
-from corgy_mdm.models import MasterDataModel
+from customers.models import Customer
 
 class NewsFeed(Feed):
     title = "News."
@@ -8,7 +8,7 @@ class NewsFeed(Feed):
     description = "Updates on changes and additions of the situation."
 
     def items(self):
-        return MasterDataModel.objects.order_by('-pub_date')[:5]
+        return Customer.objects.order_by('-pub_date')[:5]
 
     def item_title(self, item):
         return item.title
